@@ -12,8 +12,9 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from unittest import mock
+
 from oslotest import base
-from six.moves import mock
 
 from sushy_tools.emulator.resources.vmedia.staticdriver import StaticDriver
 
